@@ -15,29 +15,13 @@ from unittest.mock import MagicMock, patch
 from pontos.testing import temp_file
 
 from greenbone.feed.sync.config import (
-    DEFAULT_CERT_DATA_PATH,
-    DEFAULT_CERT_DATA_URL_PATH,
     DEFAULT_CONFIG_FILE,
     DEFAULT_DESTINATION_PREFIX,
     DEFAULT_ENTERPRISE_KEY_PATH,
-    DEFAULT_GVMD_DATA_PATH,
-    DEFAULT_GVMD_DATA_URL_PATH,
+    DEFAULT_FEED_RELEASE,
     DEFAULT_GVMD_LOCK_FILE_PATH,
-    DEFAULT_NASL_PATH,
-    DEFAULT_NASL_URL_PATH,
-    DEFAULT_NOTUS_PATH,
-    DEFAULT_NOTUS_URL_PATH,
     DEFAULT_OPENVAS_LOCK_FILE_PATH,
-    DEFAULT_PORT_LISTS_PATH,
-    DEFAULT_PORT_LISTS_URL_PATH,
-    DEFAULT_REPORT_FORMATS_PATH,
-    DEFAULT_REPORT_FORMATS_URL_PATH,
-    DEFAULT_SCAN_CONFIGS_PATH,
-    DEFAULT_SCAN_CONFIGS_URL_PATH,
-    DEFAULT_SCAP_DATA_PATH,
-    DEFAULT_SCAP_DATA_URL_PATH,
     DEFAULT_USER_CONFIG_FILE,
-    DEFAULT_VERSION,
 )
 from greenbone.feed.sync.errors import ConfigFileError
 from greenbone.feed.sync.helper import DEFAULT_FLOCK_WAIT_INTERVAL
@@ -126,65 +110,79 @@ class CliParserTestCase(unittest.TestCase):
         self.assertEqual(args.feed_url, DEFAULT_RSYNC_URL)
         self.assertEqual(
             args.gvmd_data_destination,
-            Path(DEFAULT_DESTINATION_PREFIX) / DEFAULT_GVMD_DATA_PATH,
+            Path(DEFAULT_DESTINATION_PREFIX) / "gvm" / "data-objects" / "gvmd",
         )
         self.assertEqual(
             args.gvmd_data_url,
-            f"{DEFAULT_RSYNC_URL}{DEFAULT_GVMD_DATA_URL_PATH}",
+            f"{DEFAULT_RSYNC_URL}/data-feed/{DEFAULT_FEED_RELEASE}/",
         )
         self.assertEqual(
             args.notus_destination,
-            Path(DEFAULT_DESTINATION_PREFIX) / DEFAULT_NOTUS_PATH,
+            Path(DEFAULT_DESTINATION_PREFIX) / "notus",
         )
         self.assertEqual(
-            args.notus_url, f"{DEFAULT_RSYNC_URL}{DEFAULT_NOTUS_URL_PATH}"
+            args.notus_url,
+            f"{DEFAULT_RSYNC_URL}/vulnerability-feed/{DEFAULT_FEED_RELEASE}/vt-data/notus/",
         )
         self.assertEqual(
             args.nasl_destination,
-            Path(DEFAULT_DESTINATION_PREFIX) / DEFAULT_NASL_PATH,
+            Path(DEFAULT_DESTINATION_PREFIX) / "openvas" / "plugins",
         )
         self.assertEqual(
-            args.nasl_url, f"{DEFAULT_RSYNC_URL}{DEFAULT_NASL_URL_PATH}"
+            args.nasl_url,
+            f"{DEFAULT_RSYNC_URL}/vulnerability-feed/{DEFAULT_FEED_RELEASE}/vt-data/nasl/",
         )
         self.assertEqual(
             args.scap_data_destination,
-            Path(DEFAULT_DESTINATION_PREFIX) / DEFAULT_SCAP_DATA_PATH,
+            Path(DEFAULT_DESTINATION_PREFIX) / "gvm" / "scap-data",
         )
         self.assertEqual(
             args.scap_data_url,
-            f"{DEFAULT_RSYNC_URL}{DEFAULT_SCAP_DATA_URL_PATH}",
+            f"{DEFAULT_RSYNC_URL}/vulnerability-feed/{DEFAULT_FEED_RELEASE}/scap-data/",
         )
         self.assertEqual(
             args.cert_data_destination,
-            Path(DEFAULT_DESTINATION_PREFIX) / DEFAULT_CERT_DATA_PATH,
+            Path(DEFAULT_DESTINATION_PREFIX) / "gvm" / "cert-data",
         )
         self.assertEqual(
             args.cert_data_url,
-            f"{DEFAULT_RSYNC_URL}{DEFAULT_CERT_DATA_URL_PATH}",
+            f"{DEFAULT_RSYNC_URL}/vulnerability-feed/{DEFAULT_FEED_RELEASE}/cert-data/",
         )
         self.assertEqual(
             args.report_formats_destination,
-            Path(DEFAULT_DESTINATION_PREFIX) / DEFAULT_REPORT_FORMATS_PATH,
+            Path(DEFAULT_DESTINATION_PREFIX)
+            / "gvm"
+            / "data-objects"
+            / "gvmd"
+            / "report-formats",
         )
         self.assertEqual(
             args.report_formats_url,
-            f"{DEFAULT_RSYNC_URL}{DEFAULT_REPORT_FORMATS_URL_PATH}",
+            f"{DEFAULT_RSYNC_URL}/data-feed/{DEFAULT_FEED_RELEASE}/report-formats/",
         )
         self.assertEqual(
             args.scan_configs_destination,
-            Path(DEFAULT_DESTINATION_PREFIX) / DEFAULT_SCAN_CONFIGS_PATH,
+            Path(DEFAULT_DESTINATION_PREFIX)
+            / "gvm"
+            / "data-objects"
+            / "gvmd"
+            / "scan-configs",
         )
         self.assertEqual(
             args.scan_configs_url,
-            f"{DEFAULT_RSYNC_URL}{DEFAULT_SCAN_CONFIGS_URL_PATH}",
+            f"{DEFAULT_RSYNC_URL}/data-feed/{DEFAULT_FEED_RELEASE}/scan-configs/",
         )
         self.assertEqual(
             args.port_lists_destination,
-            Path(DEFAULT_DESTINATION_PREFIX) / DEFAULT_PORT_LISTS_PATH,
+            Path(DEFAULT_DESTINATION_PREFIX)
+            / "gvm"
+            / "data-objects"
+            / "gvmd"
+            / "port-lists",
         )
         self.assertEqual(
             args.port_lists_url,
-            f"{DEFAULT_RSYNC_URL}{DEFAULT_PORT_LISTS_URL_PATH}",
+            f"{DEFAULT_RSYNC_URL}/data-feed/{DEFAULT_FEED_RELEASE}/port-lists/",
         )
         self.assertEqual(
             args.gvmd_lock_file,
@@ -207,6 +205,7 @@ class CliParserTestCase(unittest.TestCase):
             args.greenbone_enterprise_feed_key,
             Path(DEFAULT_ENTERPRISE_KEY_PATH),
         )
+        self.assertEqual(args.feed_release, DEFAULT_FEED_RELEASE)
 
     def test_help(self):
         parser = CliParser()
@@ -302,8 +301,7 @@ class CliParserTestCase(unittest.TestCase):
             parser.parse_arguments(["--compression-level", "10"])
 
         self.assertIn(
-            "error: argument --compression-level: invalid choice: 10 "
-            "(choose from 0, 1, 2, 3, 4, 5, 6, 7, 8, 9)",
+            "error: argument --compression-level: invalid choice:",
             f.getvalue(),
         )
 
@@ -733,35 +731,35 @@ sed diam nonumy eirmod tempor
             )
             self.assertEqual(
                 args.gvmd_data_url,
-                f"ssh://a_user@some.feed.server/enterprise/data-feed/{DEFAULT_VERSION}/",
+                f"ssh://a_user@some.feed.server/enterprise/data-feed/{DEFAULT_FEED_RELEASE}/",
             )
             self.assertEqual(
                 args.port_lists_url,
-                f"ssh://a_user@some.feed.server/enterprise/data-feed/{DEFAULT_VERSION}/port-lists/",
+                f"ssh://a_user@some.feed.server/enterprise/data-feed/{DEFAULT_FEED_RELEASE}/port-lists/",
             )
             self.assertEqual(
                 args.report_formats_url,
-                f"ssh://a_user@some.feed.server/enterprise/data-feed/{DEFAULT_VERSION}/report-formats/",
+                f"ssh://a_user@some.feed.server/enterprise/data-feed/{DEFAULT_FEED_RELEASE}/report-formats/",
             )
             self.assertEqual(
                 args.scan_configs_url,
-                f"ssh://a_user@some.feed.server/enterprise/data-feed/{DEFAULT_VERSION}/scan-configs/",
+                f"ssh://a_user@some.feed.server/enterprise/data-feed/{DEFAULT_FEED_RELEASE}/scan-configs/",
             )
             self.assertEqual(
                 args.notus_url,
-                f"ssh://a_user@some.feed.server/enterprise/vulnerability-feed/{DEFAULT_VERSION}/vt-data/notus/",
+                f"ssh://a_user@some.feed.server/enterprise/vulnerability-feed/{DEFAULT_FEED_RELEASE}/vt-data/notus/",
             )
             self.assertEqual(
                 args.nasl_url,
-                f"ssh://a_user@some.feed.server/enterprise/vulnerability-feed/{DEFAULT_VERSION}/vt-data/nasl/",
+                f"ssh://a_user@some.feed.server/enterprise/vulnerability-feed/{DEFAULT_FEED_RELEASE}/vt-data/nasl/",
             )
             self.assertEqual(
                 args.scap_data_url,
-                f"ssh://a_user@some.feed.server/enterprise/vulnerability-feed/{DEFAULT_VERSION}/scap-data/",
+                f"ssh://a_user@some.feed.server/enterprise/vulnerability-feed/{DEFAULT_FEED_RELEASE}/scap-data/",
             )
             self.assertEqual(
                 args.cert_data_url,
-                f"ssh://a_user@some.feed.server/enterprise/vulnerability-feed/{DEFAULT_VERSION}/cert-data/",
+                f"ssh://a_user@some.feed.server/enterprise/vulnerability-feed/{DEFAULT_FEED_RELEASE}/cert-data/",
             )
 
     def test_ignore_non_existing_enterprise_feed_key(self):
@@ -775,35 +773,35 @@ sed diam nonumy eirmod tempor
         )
         self.assertEqual(
             args.gvmd_data_url,
-            f"rsync://feed.community.greenbone.net/community/data-feed/{DEFAULT_VERSION}/",
+            f"rsync://feed.community.greenbone.net/community/data-feed/{DEFAULT_FEED_RELEASE}/",
         )
         self.assertEqual(
             args.port_lists_url,
-            f"rsync://feed.community.greenbone.net/community/data-feed/{DEFAULT_VERSION}/port-lists/",
+            f"rsync://feed.community.greenbone.net/community/data-feed/{DEFAULT_FEED_RELEASE}/port-lists/",
         )
         self.assertEqual(
             args.report_formats_url,
-            f"rsync://feed.community.greenbone.net/community/data-feed/{DEFAULT_VERSION}/report-formats/",
+            f"rsync://feed.community.greenbone.net/community/data-feed/{DEFAULT_FEED_RELEASE}/report-formats/",
         )
         self.assertEqual(
             args.scan_configs_url,
-            f"rsync://feed.community.greenbone.net/community/data-feed/{DEFAULT_VERSION}/scan-configs/",
+            f"rsync://feed.community.greenbone.net/community/data-feed/{DEFAULT_FEED_RELEASE}/scan-configs/",
         )
         self.assertEqual(
             args.notus_url,
-            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{DEFAULT_VERSION}/vt-data/notus/",
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{DEFAULT_FEED_RELEASE}/vt-data/notus/",
         )
         self.assertEqual(
             args.nasl_url,
-            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{DEFAULT_VERSION}/vt-data/nasl/",
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{DEFAULT_FEED_RELEASE}/vt-data/nasl/",
         )
         self.assertEqual(
             args.scap_data_url,
-            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{DEFAULT_VERSION}/scap-data/",
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{DEFAULT_FEED_RELEASE}/scap-data/",
         )
         self.assertEqual(
             args.cert_data_url,
-            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{DEFAULT_VERSION}/cert-data/",
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{DEFAULT_FEED_RELEASE}/cert-data/",
         )
 
     @patch.object(sys, "argv", ["greenbone-nvt-sync"])
@@ -826,3 +824,195 @@ sed diam nonumy eirmod tempor
         args = parser.parse_arguments([])
 
         self.assertEqual(args.type, "cert")
+
+    def test_feed_release(self):
+        parser = CliParser()
+        feed_release = "1.2.3"
+        args = parser.parse_arguments(["--feed-release", feed_release])
+        self.assertTrue(args.feed_release, "1.2.3")
+
+        self.assertEqual(
+            args.feed_url, "rsync://feed.community.greenbone.net/community"
+        )
+        self.assertEqual(
+            args.gvmd_data_url,
+            f"rsync://feed.community.greenbone.net/community/data-feed/{feed_release}/",
+        )
+        self.assertEqual(
+            args.port_lists_url,
+            f"rsync://feed.community.greenbone.net/community/data-feed/{feed_release}/port-lists/",
+        )
+        self.assertEqual(
+            args.report_formats_url,
+            f"rsync://feed.community.greenbone.net/community/data-feed/{feed_release}/report-formats/",
+        )
+        self.assertEqual(
+            args.scan_configs_url,
+            f"rsync://feed.community.greenbone.net/community/data-feed/{feed_release}/scan-configs/",
+        )
+        self.assertEqual(
+            args.notus_url,
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{feed_release}/vt-data/notus/",
+        )
+        self.assertEqual(
+            args.nasl_url,
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{feed_release}/vt-data/nasl/",
+        )
+        self.assertEqual(
+            args.scap_data_url,
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{feed_release}/scap-data/",
+        )
+        self.assertEqual(
+            args.cert_data_url,
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{feed_release}/cert-data/",
+        )
+
+    def test_feed_version(self):
+        parser = CliParser()
+        feed_release = "1.2.3"
+        args = parser.parse_arguments(["--feed-version", feed_release])
+        self.assertTrue(args.feed_version, "1.2.3")
+        self.assertTrue(args.feed_release, "1.2.3")
+
+        self.assertEqual(
+            args.feed_url, "rsync://feed.community.greenbone.net/community"
+        )
+        self.assertEqual(
+            args.gvmd_data_url,
+            f"rsync://feed.community.greenbone.net/community/data-feed/{feed_release}/",
+        )
+        self.assertEqual(
+            args.port_lists_url,
+            f"rsync://feed.community.greenbone.net/community/data-feed/{feed_release}/port-lists/",
+        )
+        self.assertEqual(
+            args.report_formats_url,
+            f"rsync://feed.community.greenbone.net/community/data-feed/{feed_release}/report-formats/",
+        )
+        self.assertEqual(
+            args.scan_configs_url,
+            f"rsync://feed.community.greenbone.net/community/data-feed/{feed_release}/scan-configs/",
+        )
+        self.assertEqual(
+            args.notus_url,
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{feed_release}/vt-data/notus/",
+        )
+        self.assertEqual(
+            args.nasl_url,
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{feed_release}/vt-data/nasl/",
+        )
+        self.assertEqual(
+            args.scap_data_url,
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{feed_release}/scap-data/",
+        )
+        self.assertEqual(
+            args.cert_data_url,
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{feed_release}/cert-data/",
+        )
+
+    def test_feed_release_overrules_version(self):
+        parser = CliParser()
+        feed_release = "1.2.3"
+        args = parser.parse_arguments(
+            ["--feed-version", "2.3.4", "--feed-release", feed_release]
+        )
+        self.assertTrue(args.feed_version, "2.3.4")
+        self.assertTrue(args.feed_release, "1.2.3")
+
+        self.assertEqual(
+            args.feed_url, "rsync://feed.community.greenbone.net/community"
+        )
+        self.assertEqual(
+            args.gvmd_data_url,
+            f"rsync://feed.community.greenbone.net/community/data-feed/{feed_release}/",
+        )
+        self.assertEqual(
+            args.port_lists_url,
+            f"rsync://feed.community.greenbone.net/community/data-feed/{feed_release}/port-lists/",
+        )
+        self.assertEqual(
+            args.report_formats_url,
+            f"rsync://feed.community.greenbone.net/community/data-feed/{feed_release}/report-formats/",
+        )
+        self.assertEqual(
+            args.scan_configs_url,
+            f"rsync://feed.community.greenbone.net/community/data-feed/{feed_release}/scan-configs/",
+        )
+        self.assertEqual(
+            args.notus_url,
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{feed_release}/vt-data/notus/",
+        )
+        self.assertEqual(
+            args.nasl_url,
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{feed_release}/vt-data/nasl/",
+        )
+        self.assertEqual(
+            args.scap_data_url,
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{feed_release}/scap-data/",
+        )
+        self.assertEqual(
+            args.cert_data_url,
+            f"rsync://feed.community.greenbone.net/community/vulnerability-feed/{feed_release}/cert-data/",
+        )
+
+    def test_destination_prefix(self):
+        parser = CliParser()
+        destination_prefix = "/tmp/foo/bar"
+        args = parser.parse_arguments(
+            ["--destination-prefix", destination_prefix]
+        )
+
+        self.assertEqual(args.type, "all")
+        self.assertEqual(args.destination_prefix, Path(destination_prefix))
+        self.assertEqual(
+            args.gvmd_data_destination,
+            Path(destination_prefix) / "gvm" / "data-objects" / "gvmd",
+        )
+        self.assertEqual(
+            args.notus_destination,
+            Path(destination_prefix) / "notus",
+        )
+        self.assertEqual(
+            args.nasl_destination,
+            Path(destination_prefix) / "openvas" / "plugins",
+        )
+        self.assertEqual(
+            args.scap_data_destination,
+            Path(destination_prefix) / "gvm" / "scap-data",
+        )
+        self.assertEqual(
+            args.cert_data_destination,
+            Path(destination_prefix) / "gvm" / "cert-data",
+        )
+        self.assertEqual(
+            args.report_formats_destination,
+            Path(destination_prefix)
+            / "gvm"
+            / "data-objects"
+            / "gvmd"
+            / "report-formats",
+        )
+        self.assertEqual(
+            args.scan_configs_destination,
+            Path(destination_prefix)
+            / "gvm"
+            / "data-objects"
+            / "gvmd"
+            / "scan-configs",
+        )
+        self.assertEqual(
+            args.port_lists_destination,
+            Path(destination_prefix)
+            / "gvm"
+            / "data-objects"
+            / "gvmd"
+            / "port-lists",
+        )
+        self.assertEqual(
+            args.gvmd_lock_file,
+            Path(destination_prefix) / DEFAULT_GVMD_LOCK_FILE_PATH,
+        )
+        self.assertEqual(
+            args.openvas_lock_file,
+            Path(destination_prefix) / DEFAULT_OPENVAS_LOCK_FILE_PATH,
+        )
